Documentation
¶
Index ¶
- type Config
- type Option
- func OptBackground(s string) Option
- func OptBgRGBA(s string) Option
- func OptCacheDir(s string) Option
- func OptFit(s string) Option
- func OptImgOrder(s string) Option
- func OptImgPath(s string) Option
- func OptRecursive(b bool) Option
- func OptTileImgPath(s string) Option
- func OptWithAnyWindowManager(b bool) Option
- func OptWithClearCache(b bool) Option
- func OptWithLastImage(b bool) Option
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// CacheDir a "cache" directory where all the temporary files reside.
CacheDir string
// WithAnyWindowManager if true, muro will try to set wallpaper for
// current window manager, including Gnome, KDE, etc.
WithAnyWindowManager bool
// WithClearCache if true, removes all files from cache.
WithClearCache bool
// WithLastImage if true, path is set to the last image from cache.
WithLastImage bool
// ImgPath a directory with wallpaper images or a path to a single image.
ImgPath string
// TileImgPath is a path to an image that can be used for creating a tiling
// background.
TileImgPath string
// Background surrounding an image.
ent.Background
// BgRGBA contains the value of a color if Background is set to color.
BgRGBA *color.RGBA
// Fit describes how to fit an image on the desktop.
ent.Fit
// ImageOrder defines sorting of the images.
ent.ImgOrder
// Recursive is true if images are searched recursively in ImgPath.
Recursive bool
}
type Option ¶
type Option func(*Config)
func OptBackground ¶
func OptCacheDir ¶
func OptImgOrder ¶
func OptImgPath ¶
func OptRecursive ¶
func OptTileImgPath ¶ added in v0.1.0
func OptWithAnyWindowManager ¶
func OptWithClearCache ¶
func OptWithLastImage ¶
Click to show internal directories.
Click to hide internal directories.